# -*- coding: utf-8 -*-

from typing import Optional, Dict

from libastra_csp.yaml_settings import YamlSettings


class CommonSettings(YamlSettings):
    __max_mac_level_key = 'max_mac_level'
    __max_csp_time_waiting_key = 'max_csp_time_waiting'
    __file_extensions_filter = 'file_extensions_filter'
    __extension_regex = 'extension_regex'

    def __init__(self) -> None:
        super().__init__(file_path='/usr/share/astra-csp/astra-csp.yaml')

    @property
    def max_mac_level(self) -> Optional[int]:
        return self.dictionary.get(self.__max_mac_level_key)

    @max_mac_level.setter
    def max_mac_level(self, value: int) -> None:
        self.dictionary[self.__max_mac_level_key] = value

    @property
    def max_csp_time_waiting(self) -> Optional[int]:
        return self.dictionary.get(self.__max_csp_time_waiting_key)

    @max_csp_time_waiting.setter
    def max_csp_time_waiting(self, value: int) -> None:
        self.dictionary[self.__max_csp_time_waiting_key] = value

    @property
    def file_extensions_filter(self) -> Optional[Dict[str, str]]:
        return self.dictionary.get(self.__file_extensions_filter)

    @file_extensions_filter.setter
    def file_extensions_filter(self, value: Optional[Dict[str, str]]) -> None:
        self.dictionary[self.__file_extensions_filter] = value

    @property
    def extension_regex(self) -> str:
        return self.dictionary.get(self.__extension_regex)

    def validate(self) -> None:
        super().validate()
        self._check_parameter(self.__max_mac_level_key, self.max_mac_level)
