# -*- coding: utf-8 -*-

from typing import Dict, List

from importlib import import_module
from pkgutil import iter_modules
from inspect import isclass


class PluginLoader:
    @staticmethod
    def find_modules(path: str = None, prefix: str = '') -> Dict[str, object]:
        return {
            name: import_module(name)
            for finder, name, is_pkg
            in iter_modules(path, prefix)
        }

    @staticmethod
    def find_plugins(module: object, plugin_type) -> List[type]:
        plugins = []
        for element in module.__all__:
            obj = getattr(module, element)
            if isclass(obj):
                if issubclass(obj, plugin_type):
                    plugins.append(obj)

        return plugins

    @staticmethod
    def load(module, plugin_type):
        plugins = []

        for module in PluginLoader.find_modules(path=module.__path__, prefix=module.__name__ + '.').values():
            for found_type in PluginLoader.find_plugins(module=module, plugin_type=plugin_type):
                plugins.append(found_type())

        plugins.sort(key=lambda plugin: plugin.priority())

        return plugins
