# -*- coding: utf-8 -*-

from functools import wraps

from PyQt5.QtCore import QSettings, QCoreApplication

translate = QCoreApplication.translate


def check_status(function):
    @wraps(function)
    def wrapper(self, *args, **kwargs):
        return_value = function(self, *args, **kwargs)

        if self.status == QSettings.AccessError:
            message = translate('Settings',
                                'An access error occurred to "{file}" file').format(file=self.file_path)
            raise Exception(message)
        elif self.status == QSettings.FormatError:
            message = translate('Settings',
                                'File format error "{file}"').format(file=self.file_path)
            raise Exception(message)
        elif self.status != QSettings.NoError:
            message = translate('Settings',
                                'Unknown error reading configuration "{file}" file').format(file=self.file_path)
            raise Exception(message)

        return return_value

    return wrapper


class Settings:
    def __init__(self, settings: QSettings):
        self._settings = settings

    @property
    def file_path(self) -> str:
        return self._settings.fileName()

    @property
    def status(self):
        return self._settings.status()
