# -*- coding: utf-8 -*-

import os.path

from PyQt5.QtCore import QTranslator, QCoreApplication, QLibraryInfo, QLocale

from libastra_csp.utils import Utils


class Translator:
    __root_translations_path = '/usr/share/fly/translations/astra-csp'

    @classmethod
    def root_translations_path(cls) -> str:
        return cls.__root_translations_path

    @classmethod
    def load_translation(cls, prefix: str = '', directory: str = '', suffix: str = '.qm') -> bool:
        application = QCoreApplication.instance()
        translator = QTranslator(application)
        loaded = translator.load(QLocale(),
                                 '',
                                 prefix,
                                 os.path.join(cls.root_translations_path(), directory),
                                 suffix)
        if loaded:
            return application.installTranslator(translator)
        else:
            return loaded

    @classmethod
    def load_system_translations(cls) -> bool:
        application = QCoreApplication.instance()
        translator = QTranslator(application)
        loaded = translator.load('qt_' + QLocale().name(), QLibraryInfo.location(QLibraryInfo.TranslationsPath))
        if loaded:
            return application.installTranslator(translator)
        else:
            return loaded

    @classmethod
    def load_common_translations(cls) -> bool:
        return Translator.load_translation(prefix='libastra_csp_')

    @classmethod
    def load_all_translations(cls) -> bool:
        return all([Translator.load_system_translations(), Translator.load_common_translations()])
