# -*- coding: utf-8 -*-

from typing import Optional, List

from PyQt5.QtCore import QSettings, QCoreApplication

from libastra_csp.settings import Settings

translate = QCoreApplication.translate


class UserSettings(Settings):
    __last_dir_key = 'LastDir'
    __fingerprint_key = 'LastFingerprint'
    __selected_format_key = 'LastFormat'
    __selected_extension_key = 'LastExtension'
    __extensions_key = 'Extensions'

    def __init__(self) -> None:
        super().__init__(QSettings(QSettings.NativeFormat, QSettings.UserScope, 'rusbitech', 'astra-csp'))

    @property
    def last_dir(self) -> Optional[str]:
        return self._settings.value(self.__last_dir_key)

    @last_dir.setter
    def last_dir(self, value: str) -> None:
        self._settings.setValue(self.__last_dir_key, value)
        self._settings.sync()

    @property
    def fingerprint(self) -> Optional[str]:
        return self._settings.value(self.__fingerprint_key)

    @fingerprint.setter
    def fingerprint(self, value: str) -> None:
        self._settings.setValue(self.__fingerprint_key, value)
        self._settings.sync()

    @property
    def selected_format(self) -> Optional[str]:
        return self._settings.value(self.__selected_format_key)

    @selected_format.setter
    def selected_format(self, value: str) -> None:
        self._settings.setValue(self.__selected_format_key, value)
        self._settings.sync()

    @property
    def selected_extension(self) -> Optional[str]:
        return self._settings.value(self.__selected_extension_key)

    @selected_extension.setter
    def selected_extension(self, value: str) -> None:
        self._settings.setValue(self.__selected_extension_key, value)
        self._settings.sync()

    @property
    def extensions(self) -> Optional[List[str]]:
        return self._settings.value(self.__extensions_key)

    @extensions.setter
    def extensions(self, value: List[str]) -> None:
        self._settings.setValue(self.__extensions_key, value)
        self._settings.sync()
