# -*- coding: utf-8 -*-

import os

from typing import List

from PyQt5.QtCore import QMimeDatabase, QDir, QByteArray, QProcess, QCoreApplication, QLocale


translate = QCoreApplication.translate


class Utils:
    @classmethod
    def file_path(cls, package_path: str,  *paths) -> str:
        package_directory = os.path.dirname(os.path.abspath(package_path))
        return os.path.join(package_directory, *paths)

    @staticmethod
    def get_lang() -> str:
        return QLocale().name()[:2]

    @staticmethod
    def file_is_exists(path: str) -> bool:
        return os.path.isfile(path)

    @staticmethod
    def file_size(path: str) -> int:
        return os.stat(path).st_size

    @staticmethod
    def dir_is_exists(path: str) -> bool:
        return os.path.isdir(path)

    @staticmethod
    def readfile(file_path: str) -> List[str]:
        with open(file_path, 'r') as file:
            lines = file.readlines()
        return lines

    @staticmethod
    def readall(file_path: str) -> str:
        content = ''
        with open(file_path, 'r') as file:
            content = file.read()
        return content

    @staticmethod
    def get_mac_level() -> int:
        process = QProcess()
        process.start('pdp-id -l')
        process.waitForFinished()
        if process.exitStatus() != QProcess.NormalExit:
            raise Exception(process.errorString())
        elif process.exitCode() == 0:
            try:
                return int(Utils.to_utf8(process.readAll()).split('\n')[0])
            except Exception as exception:
                raise Exception(translate('text', 'Failed read "pdp-id -l" process output. {text}')
                                .format(text=str(exception)))
        else:
            if not os.path.exists('/parsecfs/ctl'):
                return 0

            output = Utils.to_utf8(process.readAllStandardError())
            raise Exception(output if len(output) > 0 else process.errorString())

    @staticmethod
    def file_mimetypes(path: str) -> str:
        return QMimeDatabase().mimeTypeForFile(path).name()

    @staticmethod
    def create_directory(path: str) -> bool:
        return QDir(path).mkpath('.')

    @staticmethod
    def delete_directory(path: str) -> bool:
        return QDir(path).removeRecursively()

    @staticmethod
    def to_utf8(array: QByteArray) -> str:
        return str(array.data(), 'utf-8', 'ignore')

    @staticmethod
    def execute(program: str, args: List[str]) -> None:
        returncode = QProcess.execute(program, args)
        if returncode != 0:
            message = translate('text',
                                'Command "{program} {args}" exited with code {code}').format(program=program,
                                                                                             args=' '.join(args),
                                                                                             code=returncode)
            raise RuntimeError(message)
