# -*- coding: utf-8 -*-

import yaml
import os

from typing import Optional

from PyQt5.QtCore import QCoreApplication


translate = QCoreApplication.translate


class YamlSettings:
    def __init__(self, file_path: str) -> None:
        super().__init__()
        self.__file_path = file_path
        self.__dictionary = {}
        self.__error = None  # type: Optional[str]

    @property
    def file_path(self) -> str:
        return self.__file_path

    @property
    def override_file_path(self) -> str:
        return os.path.join('/etc/astra-csp', os.path.basename(self.__file_path))

    @property
    def dictionary(self) -> dict:
        return self.__dictionary

    @property
    def error(self) -> Optional[str]:
        return self.__error

    @staticmethod
    def write(path: str, data) -> None:
        dir_path = os.path.dirname(path)
        if not os.path.exists(dir_path):
            os.makedirs(name=dir_path, exist_ok=True)

        with open(path, mode='w', encoding='utf-8') as file:
            yaml.dump(data, stream=file)

    def load(self) -> None:
        try:
            with open(self.__file_path, 'r') as file:
                self.__dictionary.update(yaml.load(file) or {})
                self.__load_override_file()
        except Exception as exception:
            self.__error = str(exception)

    def validate(self) -> None:
        pass

    def serialize(self) -> Optional[str]:
        try:
            return yaml.dump(self.dictionary)
        except yaml.YAMLError as exception:
            self.__error = str(exception)
            return

    def _check_parameter(self, parameter: str, value) -> None:
        if value is None:
            message = translate('Settings',
                                'Parameter "{parameter}" is not set in "{file}" configuration file') \
                .format(parameter=parameter, file=self.__file_path)

            raise Exception(message)

    def __load_override_file(self) -> None:
        if os.path.exists(self.override_file_path):
            with open(self.override_file_path, 'r') as file:
                self.__dictionary.update(yaml.load(file) or {})
